@@ -22,7 +22,8 @@ from psyplot_gui.compat.qtcompat import (
 from psyplot_gui.common import get_icon, DockMixin, PyErrorMessage
 from IPython.core.oinspect import signature, getdoc
 import logging
-from psyplot_gui.common import get_module_path, StreamToLogger
+from psyplot_gui.common import get_module_path, StreamToLogger, \
+    is_running_tests
 from tempfile import mkdtemp
 try:
     from sphinx.application import Sphinx
@@ -62,6 +63,9 @@ def html2file(url):
                                 p.path[int(sys.platform == 'win32'):]))
 
 
+_viewers = OrderedDict()
+
+
 logger = logging.getLogger(__name__)
 
 
@@ -174,6 +178,14 @@ class UrlBrowser(QFrame):
     #: The upper most layout aranging the button box and the html widget
     vbox = None
 
+    #: default value for :attr:`bt_lock`. Is set during browser
+    #: initialization
+    bt_lock_default = None
+
+    #: default value for :attr:`bt_url_lock`. Is set during browser
+    #: initialization
+    bt_url_lock_default = None
+
     def __init__(self, *args, **kwargs):
         super(UrlBrowser, self).__init__(*args, **kwargs)
 
@@ -265,6 +277,9 @@ class UrlBrowser(QFrame):
         if self.default_url is not None:
             self.tb_url.addItem(self.default_url)
 
+        self.bt_lock_default = bool(self.bt_lock.isChecked())
+        self.bt_url_lock_default = bool(self.bt_url_lock.isChecked())
+
     def browse(self, url):
         """Make a web browse on the given url and show the page on the Webview
         widget. """
@@ -800,7 +815,8 @@ class UrlHelp(UrlBrowser, HelpMixin):
             lines, descriptor))
 
     def close(self, *args, **kwargs):
-        if self.sphinx_thread is not None:
+        if kwargs.pop('force', False) or (
+                not is_running_tests() and self.sphinx_thread is not None):
             try:
                 del self.sphinx_thread.app
             except AttributeError:
@@ -809,7 +825,12 @@ class UrlHelp(UrlBrowser, HelpMixin):
             if self._temp_dir:
                 shutil.rmtree(self.sphinx_dir, ignore_errors=True)
             del self.sphinx_thread
-        return super(UrlHelp, self).close(*args, **kwargs)
+            return super(UrlHelp, self).close(*args, **kwargs)
+        elif is_running_tests():
+            self.bt_url_lock.setChecked(self.bt_url_lock_default)
+            self.bt_lock.setChecked(self.bt_lock_default)
+        else:
+            return super(UrlHelp, self).close(*args, **kwargs)
 
 
 class SphinxThread(QtCore.QThread):
@@ -917,9 +938,20 @@ class HelpExplorer(QWidget, DockMixin):
         self.vbox = vbox = QVBoxLayout()
         self.combo = QComboBox(parent=self)
         vbox.addWidget(self.combo)
-        self.viewers = OrderedDict(
-            [(key, cls(parent=self)) for key, cls in six.iteritems(
-                self.viewers)])
+        if _viewers:
+            self.viewers = _viewers.copy()
+            for w in self.viewers.values():
+                w.setParent(self)
+        else:
+            self.viewers = OrderedDict(
+                [(key, cls(parent=self)) for key, cls in six.iteritems(
+                    self.viewers)])
+            # save the UrlHelp because QWebEngineView creates child processes
+            # that are not properly closed by PyQt and as such use too much
+            # memory
+            if is_running_tests():
+                for key, val in self.viewers.items():
+                    _viewers[key] = val
         for key, ini in six.iteritems(self.viewers):
             self.combo.addItem(key)
             ini.hide()
@@ -1035,5 +1067,8 @@ class HelpExplorer(QWidget, DockMixin):
                 found = True
 
     def close(self, *args, **kwargs):
-        self.viewers['HTML help'].close(*args, **kwargs)
+        try:
+            self.viewers['HTML help'].close(*args, **kwargs)
+        except AttributeError:
+            pass
         return super(HelpExplorer, self).close(*args, **kwargs)
